@@ -28,3 +28,21 @@ class InvalidEventListenerIdException(Exception):
 
 class NoRegisteredEventListenerException(Exception):
     pass
+
+
+# Nexity
+class NexityBadCredentialsException(Exception):
+    pass
+
+
+class NexityServiceException(Exception):
+    pass
+
+
+# CozyTouch
+class CozyTouchBadCredentialsException(Exception):
+    pass
+
+
+class CozyTouchServiceException(Exception):
+    pass
